@@ -19,16 +19,13 @@ import unittest
 import testresources
 from testscenarios import generate_scenarios
 from testtools import TestCase
+from testtools.testresult.doubles import ExtendedTestResult
+from testtools.testresult.real import MultiTestResult
+
 
 class ResourcedTestCase(TestCase, testresources.ResourcedTestCase):
     """Make all testrepository tests have resource support."""
 
-    def setUp(self):
-        TestCase.setUp(self)
-        testresources.ResourcedTestCase.setUpResources(self)
-        self.addCleanup(testresources.ResourcedTestCase.tearDownResources,
-            self)
-
 
 class _Wildcard(object):
     """Object that is equal to everything."""
@@ -46,6 +43,20 @@ class _Wildcard(object):
 Wildcard = _Wildcard()
 
 
+class StubTestCommand:
+
+    def __init__(self):
+        self.results = []
+
+    def __call__(self, ui, repo):
+        return self
+
+    def make_result(self, receiver):
+        result = ExtendedTestResult()
+        self.results.append(result)
+        return MultiTestResult(result, receiver)
+
+
 def test_suite():
     packages = [
         'arguments',
